' Maximite modifications by John Gerrard

'     to Maximite I2C   D7  D6   D5  D4
'           ^   ^       |   |    |   |
'       +3.3|   |       |   |    |   |
'       |   |   |   |   |   |    |   |
'     +-+---+---+---+---+---+---+---+-+
'     | V+ SDA SCD INT  P7  P6  P5  P4|
'     |                               |
'      D    PCF8574 port expander     |
'     |                               |
'     | A0  A1  A2  P0  P1  P2  P3 GND|
'     +-+---+---+---+---+---+---+---+-+
'       |   |   |   |   |   |   |   |
'       +---+---+   |   |   |   +------------------------+ BackLight Cnt
'       |           |   |   +------------------------+ E
'      gnd          |   +------------------------+ RW
'                   +-------------------+ RS
'
'


I2CEN 100,100 ' Enable I2C
I2CAddr  = &H20        ' this is the 8574 I2C address
                       ' A2=A1=A0=0 <-> x100 000x

'Name      8574 bit     LCD
'----      --------     ---
'DB4       = 4          ' LCD Data Line 4 (pin 11)
'DB5       = 5          ' LCD Data Line 5 (pin 12)
'DB6       = 6          ' LCD Data Line 6 (pin 13)
'DB7       = 7          ' LCD Data Line 7 (pin 14)
'RS        = 0          ' 0 = Command   1 = Data (pin 4)
'RW        = 1          ' LCD R/W (Noramlly low)
'E         = 2          ' 0 = Idle      1 = Active (pin 6)
'BL        = 3          ' Backlight on/off

RSCMDmask = &B00000000 ' Select Command register
RSDATmask = &B00000001 ' Select Data register = High P0 on 8574
Emask     = &B00000100 ' Enable = P2 on 8574

Dim CNT(6)

CNT(0) = &H33           ' %0011---- %0011----   8-bit / 8-bit 110011-
CNT(1) = &H32           ' %0011---- %0010----   8-bit / 4-bit 110010-100011

' Byte commands - To configure the LCD

                        '
                        ' Display Format
                        ' 4bit mode, 2 lines, 5x7
                        '
                        '  001LNF00
CNT(2) = &B00101000     ' %00101000
                        ' L : 0 = 4-bit Mode    1 = 8-bit Mode
                        ' N : 0 = 1 Line        1 = 2 Lines
                        ' F : 0 = 5x7 Pixels    1 = N/A

                        ' Setup Display
                        ' Display ON, Cursor On, Cursor Steady
                        '  00001DCB
CNT(3) = &B00001110     ' %00001110
                        ' D : 0 = Display Off   1 = Display On
                        ' C : 0 = Cursor Off    1 = Cursor On
                        ' B : 0 = Cursor Steady 1 = Cursor Flash

                        ' Setup Cursor/Display
                        ' Inc Cursor Cursor Move
                        '  000001IS
CNT(4) =  &B000001100   ' %000001IS   Cursor Move
                        ' I : 0 = Dec Cursor    1 = Inc Cursor
                        ' S : 0 = Cursor Move   1 = Display Shift

            CNT(5) =  &B0000001    ' Clear Screen

InitialiseLcd           ' Initialise the LCD

Light = &B1000          ' 1000 BackLight On
                        ' 0000 BackLight Off
Menu:

'To add variable values
B=10 ' Some value
B$=Str$(B) ' Convert to string

LCDLine 1, "LCD I2C Test"         ' Add your text here
LCDLine 2, "And on Line 2 " + B$  ' And here
'LCDline 3, "And on Line 3"        ' Add your text here
'LCDLine 4, "And on Line 4"        ' And here

Pause 2000
ClearScreen                ' Clear Screen

GoTo Menu


' I2C LCD
Sub ClearScreen
    aByte = CNT(5)         'Clear Screen
    SendData "Cmd"
End Sub

Sub LCDLine (Position, Line$)

 If Position = 1 Then        ' Put cursor at start of Line Position
      aByte = &H2
    ElseIf Position = 2 Then
      aByte = &HC0
    ElseIf Position = 3 Then
      aByte = &H94
    ElseIf Position = 4 Then
      aByte = &HD4
EndIf

  SendData "Cmd"

 For i = 1 To Len(Line$)
    aByte = Asc(Mid$(Line$, i, 1))
    SendData
  Next i
End Sub


'  INITIALIZE LCD
' -----------------------------------------------------------------
'
Sub InitialiseLcd
    For index = 0 To 5
      aByte =  CNT(index)
      SendData "Cmd"
    Next
End Sub

' SEND CMD BYTE - SEND DATA BYTE
' -----------------------------------------------------------------

Sub SendData (Type$)
      If Type$="Cmd" Then
         rsbit = RSCMDmask                ' Send to Command register
      Else
      EndIf

	  ' put MSB OUT 1st
    temp = (aByte \ &B10000)
    temp = (temp * 16) Or rsbit

        I2COUT

    ' put LSB
    temp = aByte And &H0F
    ' Send to Data register next
    Temp = ((temp * 16) Or rsbit) Or Light
    rsbit = RSDATmask

        I2COUT

    Type$=""
End Sub

Sub I2COUT
      temp = temp Xor Emask            ' E=1
I2CSEND i2caddr, 0, 1, temp            ' send to 8574
  Pause 2
     temp = temp Xor Emask             ' E=0
I2CSEND i2caddr, 0, 1, temp

End Sub

